@@ -1,5 +1,6 @@
 /*
     SPDX-FileCopyrightText: 2009 David Edmundson <kde@davidedmundson.co.uk>
+    SPDX-FileCopyrightText: 2022 Harald Sitter <sitter@kde.org>
 
     SPDX-License-Identifier: GPL-2.0-only OR GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL
 */
@@ -7,9 +8,9 @@
 #ifndef LOADVIEW_H
 #define LOADVIEW_H
 
-#include <QWidget>
-#include <QUrl>
 #include "ui_loadView.h"
+#include <QUrl>
+#include <QWidget>
 
 namespace Dragon
 {
@@ -19,14 +20,8 @@ class LoadView : public QWidget, private Ui_LoadView
     Q_OBJECT
 public:
     explicit LoadView(QWidget *parent);
-    void setThumbnail(QWidget *object);
-Q_SIGNALS:
-    void loadUrl(const QUrl&);
-    void openFilePressed();
-    void openDVDPressed();
-    void openStreamPressed();
-    void reloadRecentlyList();
+    void setToolbarActions(const QList<QAction *> &actions);
 };
 
 }
-#endif 
+#endif
