@@ -11,20 +11,21 @@
 #include "codeine.h"
 
 #include <QMultiMap>
-#include <QWidget>
 #include <QUrl>
+#include <QWidget>
 
-#include <Phonon/Path>
+#include <Phonon/Global>
 #include <Phonon/MediaSource>
 #include <Phonon/ObjectDescription>
-#include <Phonon/Global>
+#include <Phonon/Path>
 
 #include <Solid/Device>
 
 class QActionGroup;
 class QTimer;
 
-namespace Phonon {
+namespace Phonon
+{
 class VideoWidget;
 class AudioOutput;
 class MediaObject;
@@ -42,16 +43,15 @@ public:
     static VideoWindow *s_instance;
 
 private:
-    VideoWindow( const VideoWindow& ); //disable
-    VideoWindow &operator=( const VideoWindow& ); //disable
+    VideoWindow(const VideoWindow &); // disable
+    VideoWindow &operator=(const VideoWindow &); // disable
     void eject();
 
-    QTimer* m_cursorTimer;
+    QTimer *m_cursorTimer;
     bool m_justLoaded;
-    bool m_adjustedSize;
-    QActionGroup* m_subLanguages;
-    QActionGroup* m_audioLanguages;
-    QWidget* m_logo;
+    QActionGroup *m_subLanguages;
+    QActionGroup *m_audioLanguages;
+    QWidget *m_logo;
     bool m_isPreview;
     quint64 m_initialOffset;
 
@@ -59,40 +59,39 @@ private:
     Phonon::AudioOutput *m_aOutput;
     Phonon::MediaObject *m_media;
     Phonon::MediaController *m_controller;
-    Phonon::AudioDataOutput* m_aDataOutput;
+    Phonon::AudioDataOutput *m_aDataOutput;
     Phonon::Path m_audioPath;
     Phonon::Path m_audioDataPath;
 
     friend class TheStream;
 
     template<class ChannelDescription, class Func>
-    void updateActionGroup( QActionGroup* channelActions, const QList<ChannelDescription>& availableChannels
-                            , Func actionSlot );
+    void updateActionGroup(QActionGroup *channelActions, const QList<ChannelDescription> &availableChannels, Func actionSlot);
 
 public:
-    explicit VideoWindow( QWidget *parent );
+    explicit VideoWindow(QWidget *parent);
     ~VideoWindow() override;
 
     bool init();
 
-    bool load( const QUrl &url );
-    bool load( const QList<QUrl> &urls );
-    bool play( qint64 = 0 );
+    bool load(const QUrl &url);
+    bool load(const QList<QUrl> &urls);
+    bool play(qint64 = 0);
     bool resume();
     bool playDvd();
-    bool playDisc( const Solid::Device& );
+    bool playDisc(const Solid::Device &);
     bool isMuted();
     bool isPreview(const bool &v = 0);
-    void relativeSeek( qint64 );
+    void relativeSeek(qint64);
 
     qint64 length() const;
     bool isDVD() const;
 
-    bool setupAnalyzer(QObject* analyzer); ///return whether setup was successful
+    bool setupAnalyzer(QObject *analyzer); /// return whether setup was successful
 
-    ///stuff for dbus:
+    /// stuff for dbus:
     qreal volume() const;
-    void setVolume( qreal );
+    void setVolume(qreal);
     QString urlOrDisc() const;
     QMultiMap<QString, QString> metaData() const;
     Phonon::MediaSource::Type mediaSourceType() const;
@@ -100,8 +99,8 @@ public:
     qint32 tickInterval() const;
     //}
 
-    QWidget* newPositionSlider();
-    QWidget* newVolumeSlider();
+    QWidget *newPositionSlider();
+    QWidget *newVolumeSlider();
     void loadSettings();
 
     Phonon::State state() const;
@@ -112,19 +111,19 @@ public:
     static const uint CURSOR_HIDE_TIMEOUT = 2000;
 
     qint64 currentTime() const;
-    int videoSetting( const QString& );
+    int videoSetting(const QString &);
 
 public Q_SLOTS:
     void pause();
     void playPause();
-    void seek( qint64 );
+    void seek(qint64);
     void stop();
-    void stateChanged( Phonon::State, Phonon::State );
-    void settingChanged( int );
-    void mute( bool );
+    void stateChanged(Phonon::State, Phonon::State);
+    void settingChanged(int);
+    void mute(bool);
 
     void toggleDVDMenu();
-    void showOSD( const QString& );
+    void showOSD(const QString &);
     void slotSetSubtitle();
     void slotSetAudio();
     void resetZoom();
@@ -143,36 +142,42 @@ public Q_SLOTS:
     bool canGoNext() const;
 
 protected:
-    bool event( QEvent* e ) override;
-    void contextMenuEvent( QContextMenuEvent * event ) override;
-    void mouseDoubleClickEvent( QMouseEvent* ) override;
+    bool event(QEvent *e) override;
+    void contextMenuEvent(QContextMenuEvent *event) override;
+    void mouseDoubleClickEvent(QMouseEvent *) override;
     QSize sizeHint() const override;
-    Phonon::State state( Phonon::State state ) const;
-    void setSubtitle( int channel );
-    void setAudioChannel( int channel );
+    Phonon::State state(Phonon::State state) const;
+    void setSubtitle(int channel);
+    void setAudioChannel(int channel);
 private Q_SLOTS:
     void updateChannels();
     void hideCursor();
 Q_SIGNALS:
-    void stateUpdated( const Phonon::State, const Phonon::State );
-    void subChannelsChanged( QList< QAction* > );
-    void audioChannelsChanged( QList< QAction* > );
-    void tick( qint64 );
-    void currentSourceChanged( const Phonon::MediaSource);
-    void totalTimeChanged( qint64 );
-    void mutedChanged( bool );
-    void seekableChanged( bool );
+    void stateUpdated(const Phonon::State, const Phonon::State);
+    void subChannelsChanged(QList<QAction *>);
+    void audioChannelsChanged(QList<QAction *>);
+    void tick(qint64);
+    void currentSourceChanged(const Phonon::MediaSource);
+    void totalTimeChanged(qint64);
+    void mutedChanged(bool);
+    void seekableChanged(bool);
     void metaDataChanged();
-    void hasVideoChanged( bool );
-    void volumeChanged( qreal );
+    void hasVideoChanged(bool);
+    void volumeChanged(qreal);
     void finished();
 };
 
-//global function for general use by Dragon Player
+// global function for general use by Dragon Player
 
-//rearranged from previous non-static functions due to compiler warning
-static inline VideoWindow* engine() {return VideoWindow::s_instance;}
-static inline VideoWindow* videoWindow() {return VideoWindow::s_instance; }
+// rearranged from previous non-static functions due to compiler warning
+static inline VideoWindow *engine()
+{
+    return VideoWindow::s_instance;
+}
+static inline VideoWindow *videoWindow()
+{
+    return VideoWindow::s_instance;
+}
 }
 
 #endif
