@@ -16,14 +16,13 @@
 #include <KAboutData>
 #include <KProtocolInfo>
 #include <KService>
-#include <KWindowSystem>
+#include <KX11Extras>
 
-MediaPlayer2::MediaPlayer2(QObject* parent)
+MediaPlayer2::MediaPlayer2(QObject *parent)
     : QDBusAbstractAdaptor(parent)
 {
     connect(Dragon::action("fullscreen"), &QAction::toggled, this, &MediaPlayer2::emitFullscreenChange);
-    connect(Dragon::videoWindow(), &Dragon::VideoWindow::hasVideoChanged,
-            this, &MediaPlayer2::emitFullscreenChange);
+    connect(Dragon::videoWindow(), &Dragon::VideoWindow::hasVideoChanged, this, &MediaPlayer2::emitFullscreenChange);
 }
 
 MediaPlayer2::~MediaPlayer2()
@@ -48,7 +47,7 @@ bool MediaPlayer2::CanRaise() const
 void MediaPlayer2::Raise() const
 {
     Dragon::mainWindow()->raise();
-    KWindowSystem::forceActiveWindow(Dragon::mainWindow()->winId());
+    KX11Extras::forceActiveWindow(Dragon::mainWindow()->winId());
 }
 
 bool MediaPlayer2::Fullscreen() const
@@ -63,9 +62,9 @@ void MediaPlayer2::setFullscreen(bool fullscreen) const
 
 void MediaPlayer2::emitFullscreenChange(bool fullscreen) const
 {
-    const QVariantMap properties {
-        { QStringLiteral("Fullscreen"), fullscreen },
-        { QStringLiteral("CanSetFullscreen"), CanSetFullscreen()},
+    const QVariantMap properties{
+        {QStringLiteral("Fullscreen"), fullscreen},
+        {QStringLiteral("CanSetFullscreen"), CanSetFullscreen()},
     };
     Mpris2::signalPropertiesChange(this, properties);
 }
@@ -95,7 +94,7 @@ QStringList MediaPlayer2::SupportedUriSchemes() const
     QStringList protocols;
 
     const auto allProtocols = KProtocolInfo::protocols();
-    for (const QString& protocol : allProtocols) {
+    for (const QString &protocol : allProtocols) {
         if (!KProtocolInfo::isHelperProtocol(protocol))
             protocols << protocol;
     }
